@@ -22,6 +22,7 @@ class MainWindow(QWidget):
         self.wait_window = WaitWindow()
         self.debug_window = QTextEditLogger()
         self.wait_window.sigUpdateClicked.connect(self._update_version)
+        self.wait_window.sigRestartClicked.connect(self.restart)
         self.q_thread_pool = QThreadPool()
         self.worker = Worker(check_outdated, version)
         self.worker.signals.result.connect(self.wait_window.get_result)
@@ -41,8 +42,13 @@ class MainWindow(QWidget):
     @pyqtSlot(object, name='onUpdatedFinished')
     def _on_updated(self, updated: bool):
         if updated:
-            qApp = QApplication.instance()
-            qApp.closeAllWindows()
-            qApp.exit(self.EXIT_CODE_REBOOT)
+            self.wait_window.show_restart()
         else:
             self.wait_window.show_info('Auto update failed. Please, update the program manually.')
+
+    @pyqtSlot(name='restartApp')
+    def restart(self):
+        qApp = QApplication.instance()
+        qApp.closeAllWindows()
+        qApp.exit(self.EXIT_CODE_REBOOT)
+
